@@ -9,11 +9,16 @@
 #include <KConfigWatcher>
 #include <KRunner/ResultsModel>
 
+#include <qqmlregistration.h>
+
+#include <QMimeData>
+
 namespace Milou
 {
 class ResultsModel : public KRunner::ResultsModel
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(QStringList favoriteIds READ favoriteIds WRITE setFavoriteIds NOTIFY favoriteIdsChanged RESET resetFavoriteIds)
 public:
     explicit ResultsModel(QObject *parent = nullptr);
@@ -29,6 +34,12 @@ public:
         KRunner::ResultsModel::setFavoriteIds(m_configFavoriteIds);
     }
 
+    // Workaround for https://bugs.kde.org/show_bug.cgi?id=511228
+    Q_INVOKABLE QMimeData *getMimeData(const QModelIndex &idx) const
+    {
+        return KRunner::ResultsModel::getMimeData(idx);
+    }
+
 private:
     KConfigWatcher::Ptr m_configWatcher;
     QStringList m_configFavoriteIds;
